summaryrefslogtreecommitdiff
path: root/png.h
diff options
context:
space:
mode:
authorGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2009-10-31 23:28:05 -0500
committerGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2009-10-31 23:29:58 -0500
commitdc38e24fedbac541d09495fb3b561278a4d29ff7 (patch)
tree5aff6771e3c02ef0b10fd1d7cc8c5e3f3455d0b5 /png.h
parenta61724c0047f7f21ac8b0877310b73621823ef93 (diff)
downloadlibpng-dc38e24fedbac541d09495fb3b561278a4d29ff7.tar.gz
[master] Bump version to 1.2.41beta11
Diffstat (limited to 'png.h')
-rw-r--r--png.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/png.h b/png.h
index 7e6b1c30a..7980ca041 100644
--- a/png.h
+++ b/png.h
@@ -1,6 +1,6 @@
/* png.h - header file for PNG reference library
*
* libpng version 1.2.41beta10 - November 1, 2009
* Copyright (c) 1998-2009 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -10,7 +10,7 @@
* Authors and maintainers:
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
* libpng versions 0.97, January 1998, through 1.2.41beta10 - November 1, 2009: Glenn
* See also "Contributing Authors", below.
*
* Note about libpng version numbers:
@@ -245,7 +245,7 @@
* 1.2.40rc01 13 10240 12.so.0.40[.0]
* 1.0.49 10 10049 10.so.0.49[.0]
* 1.2.40 13 10240 12.so.0.40[.0]
- * 1.2.41beta01-10 13 10241 12.so.0.41[.0]
+ * 1.2.41beta01-11 13 10241 12.so.0.41[.0]
*
* Henceforth the source version will match the shared-library major
* and minor numbers; the shared-library major version number will be
@@ -277,7 +277,7 @@
*
* This code is released under the libpng license.
*
* libpng versions 1.2.6, August 15, 2004, through 1.2.41beta10, November 1, 2009, are
* Copyright (c) 2004, 2006-2009 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
* with the following individual added to the list of Contributing Authors:
@@ -395,7 +395,7 @@
* an official declaration.
*
* This is your unofficial assurance that libpng from version 0.71 and
* upward through 1.2.41beta10 are Y2K compliant. It is my belief that earlier
* versions were also Y2K compliant.
*
* Libpng only has three year fields. One is a 2-byte unsigned integer
@@ -451,9 +451,9 @@
*/
/* Version information for png.h - this should match the version in png.c */
-#define PNG_LIBPNG_VER_STRING "1.2.41beta10"
+#define PNG_LIBPNG_VER_STRING "1.2.41beta11"
#define PNG_HEADER_VERSION_STRING \
- " libpng version 1.2.41beta10 - November 1, 2009\n"
+ " libpng version 1.2.41beta11 - November 1, 2009\n"
#define PNG_LIBPNG_VER_SONUM 0
#define PNG_LIBPNG_VER_DLLNUM 13
@@ -466,7 +466,7 @@
* PNG_LIBPNG_VER_STRING, omitting any leading zero:
*/
-#define PNG_LIBPNG_VER_BUILD 10
+#define PNG_LIBPNG_VER_BUILD 11
/* Release Status */
#define PNG_LIBPNG_BUILD_ALPHA 1
@@ -1532,7 +1532,7 @@ struct png_struct_def
/* This triggers a compiler error in png.c, if png.c and png.h
* do not agree upon the version number.
*/
-typedef png_structp version_1_2_41beta10;
+typedef png_structp version_1_2_41beta11;
typedef png_struct FAR * FAR * png_structpp;
@@ -1,6 +1,6 @@
/* png.h - header file for PNG reference library
*
- * libpng version 1.2.41beta10 - November 1, 2009
+ * libpng version 1.2.41beta11 - November 1, 2009
* Copyright (c) 1998-2009 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -10,7 +10,7 @@
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- * libpng versions 0.97, January 1998, through 1.2.41beta10 - November 1, 2009: Glenn
+ * libpng versions 0.97, January 1998, through 1.2.41beta11 - November 1, 2009: Glenn
* See also "Contributing Authors", below.
*
@@ -277,7 +277,7 @@
* This code is released under the libpng license.
*
- * libpng versions 1.2.6, August 15, 2004, through 1.2.41beta10, November 1, 2009, are
+ * libpng versions 1.2.6, August 15, 2004, through 1.2.41beta11, November 1, 2009, are
* Copyright (c) 2004, 2006-2009 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
@@ -395,7 +395,7 @@
*
* This is your unofficial assurance that libpng from version 0.71 and
- * upward through 1.2.41beta10 are Y2K compliant. It is my belief that earlier
+ * upward through 1.2.41beta11 are Y2K compliant. It is my belief that earlier
* versions were also Y2K compliant.
*